[Python-checkins] r57430 - sandbox/trunk/import_in_py/zipimport_/tests.py

brett.cannon python-checkins at python.org
Sat Aug 25 01:32:53 CEST 2007


Author: brett.cannon
Date: Sat Aug 25 01:32:52 2007
New Revision: 57430

Modified:
   sandbox/trunk/import_in_py/zipimport_/tests.py
Log:
Test stub for get_code.


Modified: sandbox/trunk/import_in_py/zipimport_/tests.py
==============================================================================
--- sandbox/trunk/import_in_py/zipimport_/tests.py	(original)
+++ sandbox/trunk/import_in_py/zipimport_/tests.py	Sat Aug 25 01:32:52 2007
@@ -139,6 +139,14 @@
         raise NotImplementedError
 
 
+class GetCode(unittest.TestCase):
+
+    """Test zipimporter.get_code()."""
+
+    def test_get_code(self):
+        raise NotImplementedError
+
+
 class LoadModule(unittest.TestCase):
 
     """Test zipimporter.load_module()."""
@@ -149,7 +157,7 @@
 
 def test_main():
     test_support.run_unittest(ZipImportErrorTests, ZipImportCreation,
             FindModule, GetData, IsPackage, GetSource, LoadModule)
 
 
 if __name__ == '__main__':
@@ -149,7 +157,7 @@
 def test_main():
     test_support.run_unittest(ZipImportErrorTests, ZipImportCreation,
-            FindModule, GetData, IsPackage, GetSource, LoadModule)
+            FindModule, GetData, IsPackage, GetSource, GetCode, LoadModule)
 
 


More information about the Python-checkins mailing list